# Types

pyrmute exports some convenience types to make annotation more concise and
descriptive.

You can import them directly from `pyrmute`:

```python
from pyrmute import (
    JsonSchema,
    JsonSchemaMode,
    MigrationFunc,
    ModelData,
    NestedModelInfo,
)
```

::: pyrmute.ModelData

::: pyrmute.JsonSchema

::: pyrmute.JsonSchemaMode

::: pyrmute.NestedModelInfo

::: pyrmute.MigrationFunc
